
/* Generated data (by glib-mkenums) */

#include "lsmenumtypes.h"

/* enumerations from "lsmdomnode.h" */
#include "lsmdomnode.h"

GType
lsm_dom_node_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_DOM_NODE_TYPE_ELEMENT_NODE,
			  "LSM_DOM_NODE_TYPE_ELEMENT_NODE",
			  "element-node" },
			{ LSM_DOM_NODE_TYPE_ATTRIBUTE_NODE,
			  "LSM_DOM_NODE_TYPE_ATTRIBUTE_NODE",
			  "attribute-node" },
			{ LSM_DOM_NODE_TYPE_TEXT_NODE,
			  "LSM_DOM_NODE_TYPE_TEXT_NODE",
			  "text-node" },
			{ LSM_DOM_NODE_TYPE_CDATA_SECTION_NODE,
			  "LSM_DOM_NODE_TYPE_CDATA_SECTION_NODE",
			  "cdata-section-node" },
			{ LSM_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE,
			  "LSM_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE",
			  "entity-reference-node" },
			{ LSM_DOM_NODE_TYPE_ENTITY_NODE,
			  "LSM_DOM_NODE_TYPE_ENTITY_NODE",
			  "entity-node" },
			{ LSM_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
			  "LSM_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE",
			  "processing-instruction-node" },
			{ LSM_DOM_NODE_TYPE_COMMENT_NODE,
			  "LSM_DOM_NODE_TYPE_COMMENT_NODE",
			  "comment-node" },
			{ LSM_DOM_NODE_TYPE_DOCUMENT_NODE,
			  "LSM_DOM_NODE_TYPE_DOCUMENT_NODE",
			  "document-node" },
			{ LSM_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE,
			  "LSM_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE",
			  "document-type-node" },
			{ LSM_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
			  "LSM_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE",
			  "document-fragment-node" },
			{ LSM_DOM_NODE_TYPE_NOTATION_NODE,
			  "LSM_DOM_NODE_TYPE_NOTATION_NODE",
			  "notation-node" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmDomNodeType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmdomparser.h" */
#include "lsmdomparser.h"

GType
lsm_dom_document_error_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_DOM_DOCUMENT_ERROR_INVALID_XML,
			  "LSM_DOM_DOCUMENT_ERROR_INVALID_XML",
			  "xml" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmDomDocumentError"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlenums.h" */
#include "lsmmathmlenums.h"

GType
lsm_mathml_css_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_CSS_TYPE_USER,
			  "LSM_MATHML_CSS_TYPE_USER",
			  "user" },
			{ LSM_MATHML_CSS_TYPE_AUTHOR,
			  "LSM_MATHML_CSS_TYPE_AUTHOR",
			  "author" },
			{ LSM_MATHML_CSS_TYPE_AUTHOR_IMPORTANT,
			  "LSM_MATHML_CSS_TYPE_AUTHOR_IMPORTANT",
			  "author-important" },
			{ LSM_MATHML_CSS_TYPE_USER_IMPORTANT,
			  "LSM_MATHML_CSS_TYPE_USER_IMPORTANT",
			  "user-important" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlCssType"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_mode_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_MODE_ERROR,
			  "LSM_MATHML_MODE_ERROR",
			  "error" },
			{ LSM_MATHML_MODE_DISPLAY,
			  "LSM_MATHML_MODE_DISPLAY",
			  "display" },
			{ LSM_MATHML_MODE_INLINE,
			  "LSM_MATHML_MODE_INLINE",
			  "inline" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlMode"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_display_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_DISPLAY_ERROR,
			  "LSM_MATHML_DISPLAY_ERROR",
			  "error" },
			{ LSM_MATHML_DISPLAY_BLOCK,
			  "LSM_MATHML_DISPLAY_BLOCK",
			  "block" },
			{ LSM_MATHML_DISPLAY_INLINE,
			  "LSM_MATHML_DISPLAY_INLINE",
			  "inline" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlDisplay"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_space_name_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_SPACE_NAME_ERROR,
			  "LSM_MATHML_SPACE_NAME_ERROR",
			  "error" },
			{ LSM_MATHML_SPACE_NAME_VERY_VERY_THIN,
			  "LSM_MATHML_SPACE_NAME_VERY_VERY_THIN",
			  "very-very-thin" },
			{ LSM_MATHML_SPACE_NAME_VERY_THIN,
			  "LSM_MATHML_SPACE_NAME_VERY_THIN",
			  "very-thin" },
			{ LSM_MATHML_SPACE_NAME_THIN,
			  "LSM_MATHML_SPACE_NAME_THIN",
			  "thin" },
			{ LSM_MATHML_SPACE_NAME_MEDIUM,
			  "LSM_MATHML_SPACE_NAME_MEDIUM",
			  "medium" },
			{ LSM_MATHML_SPACE_NAME_THICK,
			  "LSM_MATHML_SPACE_NAME_THICK",
			  "thick" },
			{ LSM_MATHML_SPACE_NAME_VERY_THICK,
			  "LSM_MATHML_SPACE_NAME_VERY_THICK",
			  "very-thick" },
			{ LSM_MATHML_SPACE_NAME_VERY_VERY_THICK,
			  "LSM_MATHML_SPACE_NAME_VERY_VERY_THICK",
			  "very-very-thick" },
			{ LSM_MATHML_SPACE_NAME_INFINITY,
			  "LSM_MATHML_SPACE_NAME_INFINITY",
			  "infinity" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlSpaceName"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_unit_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_UNIT_ERROR,
			  "LSM_MATHML_UNIT_ERROR",
			  "error" },
			{ LSM_MATHML_UNIT_NONE,
			  "LSM_MATHML_UNIT_NONE",
			  "none" },
			{ LSM_MATHML_UNIT_EM,
			  "LSM_MATHML_UNIT_EM",
			  "em" },
			{ LSM_MATHML_UNIT_EX,
			  "LSM_MATHML_UNIT_EX",
			  "ex" },
			{ LSM_MATHML_UNIT_IN,
			  "LSM_MATHML_UNIT_IN",
			  "in" },
			{ LSM_MATHML_UNIT_CM,
			  "LSM_MATHML_UNIT_CM",
			  "cm" },
			{ LSM_MATHML_UNIT_MM,
			  "LSM_MATHML_UNIT_MM",
			  "mm" },
			{ LSM_MATHML_UNIT_PT,
			  "LSM_MATHML_UNIT_PT",
			  "pt" },
			{ LSM_MATHML_UNIT_PX,
			  "LSM_MATHML_UNIT_PX",
			  "px" },
			{ LSM_MATHML_UNIT_PC,
			  "LSM_MATHML_UNIT_PC",
			  "pc" },
			{ LSM_MATHML_UNIT_PERCENT,
			  "LSM_MATHML_UNIT_PERCENT",
			  "percent" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlUnit"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_font_style_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_FONT_STYLE_ERROR,
			  "LSM_MATHML_FONT_STYLE_ERROR",
			  "error" },
			{ LSM_MATHML_FONT_STYLE_NORMAL,
			  "LSM_MATHML_FONT_STYLE_NORMAL",
			  "normal" },
			{ LSM_MATHML_FONT_STYLE_ITALIC,
			  "LSM_MATHML_FONT_STYLE_ITALIC",
			  "italic" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlFontStyle"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_font_weight_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_FONT_WEIGHT_ERROR,
			  "LSM_MATHML_FONT_WEIGHT_ERROR",
			  "error" },
			{ LSM_MATHML_FONT_WEIGHT_NORMAL,
			  "LSM_MATHML_FONT_WEIGHT_NORMAL",
			  "normal" },
			{ LSM_MATHML_FONT_WEIGHT_BOLD,
			  "LSM_MATHML_FONT_WEIGHT_BOLD",
			  "bold" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlFontWeight"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_variant_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_VARIANT_ERROR,
			  "LSM_MATHML_VARIANT_ERROR",
			  "error" },
			{ LSM_MATHML_VARIANT_NORMAL,
			  "LSM_MATHML_VARIANT_NORMAL",
			  "normal" },
			{ LSM_MATHML_VARIANT_BOLD,
			  "LSM_MATHML_VARIANT_BOLD",
			  "bold" },
			{ LSM_MATHML_VARIANT_ITALIC,
			  "LSM_MATHML_VARIANT_ITALIC",
			  "italic" },
			{ LSM_MATHML_VARIANT_BOLD_ITALIC,
			  "LSM_MATHML_VARIANT_BOLD_ITALIC",
			  "bold-italic" },
			{ LSM_MATHML_VARIANT_DOUBLE_STRUCK,
			  "LSM_MATHML_VARIANT_DOUBLE_STRUCK",
			  "double-struck" },
			{ LSM_MATHML_VARIANT_FRAKTUR_BOLD,
			  "LSM_MATHML_VARIANT_FRAKTUR_BOLD",
			  "fraktur-bold" },
			{ LSM_MATHML_VARIANT_SCRIPT,
			  "LSM_MATHML_VARIANT_SCRIPT",
			  "script" },
			{ LSM_MATHML_VARIANT_SCRIPT_BOLD,
			  "LSM_MATHML_VARIANT_SCRIPT_BOLD",
			  "script-bold" },
			{ LSM_MATHML_VARIANT_FRAKTUR,
			  "LSM_MATHML_VARIANT_FRAKTUR",
			  "fraktur" },
			{ LSM_MATHML_VARIANT_SANS_SERIF,
			  "LSM_MATHML_VARIANT_SANS_SERIF",
			  "sans-serif" },
			{ LSM_MATHML_VARIANT_SANS_SERIF_BOLD,
			  "LSM_MATHML_VARIANT_SANS_SERIF_BOLD",
			  "sans-serif-bold" },
			{ LSM_MATHML_VARIANT_SANS_SERIF_ITALIC,
			  "LSM_MATHML_VARIANT_SANS_SERIF_ITALIC",
			  "sans-serif-italic" },
			{ LSM_MATHML_VARIANT_SANS_SERIF_BOLD_ITALIC,
			  "LSM_MATHML_VARIANT_SANS_SERIF_BOLD_ITALIC",
			  "sans-serif-bold-italic" },
			{ LSM_MATHML_VARIANT_MONOSPACE,
			  "LSM_MATHML_VARIANT_MONOSPACE",
			  "monospace" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlVariant"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_form_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_FORM_ERROR,
			  "LSM_MATHML_FORM_ERROR",
			  "error" },
			{ LSM_MATHML_FORM_PREFIX,
			  "LSM_MATHML_FORM_PREFIX",
			  "prefix" },
			{ LSM_MATHML_FORM_POSTFIX,
			  "LSM_MATHML_FORM_POSTFIX",
			  "postfix" },
			{ LSM_MATHML_FORM_INFIX,
			  "LSM_MATHML_FORM_INFIX",
			  "infix" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlForm"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_row_align_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_ROW_ALIGN_ERROR,
			  "LSM_MATHML_ROW_ALIGN_ERROR",
			  "error" },
			{ LSM_MATHML_ROW_ALIGN_BASELINE,
			  "LSM_MATHML_ROW_ALIGN_BASELINE",
			  "baseline" },
			{ LSM_MATHML_ROW_ALIGN_TOP,
			  "LSM_MATHML_ROW_ALIGN_TOP",
			  "top" },
			{ LSM_MATHML_ROW_ALIGN_BOTTOM,
			  "LSM_MATHML_ROW_ALIGN_BOTTOM",
			  "bottom" },
			{ LSM_MATHML_ROW_ALIGN_CENTER,
			  "LSM_MATHML_ROW_ALIGN_CENTER",
			  "center" },
			{ LSM_MATHML_ROW_ALIGN_AXIS,
			  "LSM_MATHML_ROW_ALIGN_AXIS",
			  "axis" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlRowAlign"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_column_align_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_COLUMN_ALIGN_ERROR,
			  "LSM_MATHML_COLUMN_ALIGN_ERROR",
			  "error" },
			{ LSM_MATHML_COLUMN_ALIGN_CENTER,
			  "LSM_MATHML_COLUMN_ALIGN_CENTER",
			  "center" },
			{ LSM_MATHML_COLUMN_ALIGN_LEFT,
			  "LSM_MATHML_COLUMN_ALIGN_LEFT",
			  "left" },
			{ LSM_MATHML_COLUMN_ALIGN_RIGHT,
			  "LSM_MATHML_COLUMN_ALIGN_RIGHT",
			  "right" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlColumnAlign"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_line_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_LINE_ERROR,
			  "LSM_MATHML_LINE_ERROR",
			  "error" },
			{ LSM_MATHML_LINE_NONE,
			  "LSM_MATHML_LINE_NONE",
			  "none" },
			{ LSM_MATHML_LINE_SOLID,
			  "LSM_MATHML_LINE_SOLID",
			  "solid" },
			{ LSM_MATHML_LINE_DASHED,
			  "LSM_MATHML_LINE_DASHED",
			  "dashed" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlLine"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_script_level_sign_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_ERROR,
			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_ERROR",
			  "error" },
			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_NONE,
			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_NONE",
			  "none" },
			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_PLUS,
			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_PLUS",
			  "plus" },
			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_MINUS,
			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_MINUS",
			  "minus" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlScriptLevelSign"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmltablerowelement.h" */
#include "lsmmathmltablerowelement.h"

GType
lsm_mathml_table_row_element_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_TABLE_ROW_ELEMENT_TYPE_ROW,
			  "LSM_MATHML_TABLE_ROW_ELEMENT_TYPE_ROW",
			  "row" },
			{ LSM_MATHML_TABLE_ROW_ELEMENT_TYPE_LABELED_ROW,
			  "LSM_MATHML_TABLE_ROW_ELEMENT_TYPE_LABELED_ROW",
			  "labeled-row" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlTableRowElementType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlradicalelement.h" */
#include "lsmmathmlradicalelement.h"

GType
lsm_mathml_radical_element_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_RADICAL_ELEMENT_TYPE_SQRT,
			  "LSM_MATHML_RADICAL_ELEMENT_TYPE_SQRT",
			  "sqrt" },
			{ LSM_MATHML_RADICAL_ELEMENT_TYPE_ROOT,
			  "LSM_MATHML_RADICAL_ELEMENT_TYPE_ROOT",
			  "root" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlRadicalElementType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlscriptelement.h" */
#include "lsmmathmlscriptelement.h"

GType
lsm_mathml_script_element_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUB,
			  "LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUB",
			  "sub" },
			{ LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUP,
			  "LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUP",
			  "sup" },
			{ LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUB_SUP,
			  "LSM_MATHML_SCRIPT_ELEMENT_TYPE_SUB_SUP",
			  "sub-sup" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlScriptElementType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlunderoverelement.h" */
#include "lsmmathmlunderoverelement.h"

GType
lsm_mathml_under_over_element_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_UNDER,
			  "LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_UNDER",
			  "under" },
			{ LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_OVER,
			  "LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_OVER",
			  "over" },
			{ LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_UNDER_OVER,
			  "LSM_MATHML_UNDER_OVER_ELEMENT_TYPE_UNDER_OVER",
			  "under-over" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlUnderOverElementType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlpresentationtoken.h" */
#include "lsmmathmlpresentationtoken.h"

GType
lsm_mathml_presentation_token_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_PRESENTATION_TOKEN_TYPE_NUMBER,
			  "LSM_MATHML_PRESENTATION_TOKEN_TYPE_NUMBER",
			  "number" },
			{ LSM_MATHML_PRESENTATION_TOKEN_TYPE_IDENTIFIER,
			  "LSM_MATHML_PRESENTATION_TOKEN_TYPE_IDENTIFIER",
			  "identifier" },
			{ LSM_MATHML_PRESENTATION_TOKEN_TYPE_TEXT,
			  "LSM_MATHML_PRESENTATION_TOKEN_TYPE_TEXT",
			  "text" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlPresentationTokenType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmmathmlview.h" */
#include "lsmmathmlview.h"

GType
lsm_mathml_glyph_flags_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ LSM_MATHML_GLYPH_FLAG_STRETCH_VERTICAL,
			  "LSM_MATHML_GLYPH_FLAG_STRETCH_VERTICAL",
			  "stretch-vertical" },
			{ LSM_MATHML_GLYPH_FLAG_STRETCH_HORIZONTAL,
			  "LSM_MATHML_GLYPH_FLAG_STRETCH_HORIZONTAL",
			  "stretch-horizontal" },
			{ LSM_MATHML_GLYPH_FLAG_TYPE_SIZED,
			  "LSM_MATHML_GLYPH_FLAG_TYPE_SIZED",
			  "type-sized" },
			{ LSM_MATHML_GLYPH_FLAG_ALIGN_AXIS,
			  "LSM_MATHML_GLYPH_FLAG_ALIGN_AXIS",
			  "align-axis" },
			{ LSM_MATHML_GLYPH_FLAG_HAS_LARGE_VERSION,
			  "LSM_MATHML_GLYPH_FLAG_HAS_LARGE_VERSION",
			  "has-large-version" },
			{ LSM_MATHML_GLYPH_FLAG_INTEGRAL_SLANT,
			  "LSM_MATHML_GLYPH_FLAG_INTEGRAL_SLANT",
			  "integral-slant" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("LsmMathmlGlyphFlags"),
				values);
	}
	return the_type;
}

GType
lsm_mathml_font_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_MATHML_FONT_ERROR,
			  "LSM_MATHML_FONT_ERROR",
			  "error" },
			{ LSM_MATHML_FONT_DEFAULT,
			  "LSM_MATHML_FONT_DEFAULT",
			  "default" },
			{ LSM_MATHML_FONT_CMR10,
			  "LSM_MATHML_FONT_CMR10",
			  "cmr10" },
			{ LSM_MATHML_FONT_CMMI10,
			  "LSM_MATHML_FONT_CMMI10",
			  "cmmi10" },
			{ LSM_MATHML_FONT_CMEX10,
			  "LSM_MATHML_FONT_CMEX10",
			  "cmex10" },
			{ LSM_MATHML_FONT_CMSY10,
			  "LSM_MATHML_FONT_CMSY10",
			  "cmsy10" },
			{ LSM_MATHML_FONT_SYMBOL,
			  "LSM_MATHML_FONT_SYMBOL",
			  "symbol" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmMathmlFont"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmsvgenums.h" */
#include "lsmsvgenums.h"

GType
lsm_svg_angle_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_ANGLE_TYPE_ERROR,
			  "LSM_SVG_ANGLE_TYPE_ERROR",
			  "error" },
			{ LSM_SVG_ANGLE_TYPE_AUTO,
			  "LSM_SVG_ANGLE_TYPE_AUTO",
			  "auto" },
			{ LSM_SVG_ANGLE_TYPE_FIXED,
			  "LSM_SVG_ANGLE_TYPE_FIXED",
			  "fixed" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgAngleType"),
				values);
	}
	return the_type;
}

GType
lsm_svg_paint_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_PAINT_TYPE_ERROR,
			  "LSM_SVG_PAINT_TYPE_ERROR",
			  "error" },
			{ LSM_SVG_PAINT_TYPE_UNKNOWN,
			  "LSM_SVG_PAINT_TYPE_UNKNOWN",
			  "unknown" },
			{ LSM_SVG_PAINT_TYPE_RGB_COLOR,
			  "LSM_SVG_PAINT_TYPE_RGB_COLOR",
			  "rgb-color" },
			{ LSM_SVG_PAINT_TYPE_RGB_COLOR_ICC_COLOR,
			  "LSM_SVG_PAINT_TYPE_RGB_COLOR_ICC_COLOR",
			  "rgb-color-icc-color" },
			{ LSM_SVG_PAINT_TYPE_NONE,
			  "LSM_SVG_PAINT_TYPE_NONE",
			  "none" },
			{ LSM_SVG_PAINT_TYPE_CURRENT_COLOR,
			  "LSM_SVG_PAINT_TYPE_CURRENT_COLOR",
			  "current-color" },
			{ LSM_SVG_PAINT_TYPE_URI_NONE,
			  "LSM_SVG_PAINT_TYPE_URI_NONE",
			  "uri-none" },
			{ LSM_SVG_PAINT_TYPE_URI_CURRENT_COLOR,
			  "LSM_SVG_PAINT_TYPE_URI_CURRENT_COLOR",
			  "uri-current-color" },
			{ LSM_SVG_PAINT_TYPE_URI_RGB_COLOR,
			  "LSM_SVG_PAINT_TYPE_URI_RGB_COLOR",
			  "uri-rgb-color" },
			{ LSM_SVG_PAINT_TYPE_URI_RGB_COLOR_ICC_COLOR,
			  "LSM_SVG_PAINT_TYPE_URI_RGB_COLOR_ICC_COLOR",
			  "uri-rgb-color-icc-color" },
			{ LSM_SVG_PAINT_TYPE_URI,
			  "LSM_SVG_PAINT_TYPE_URI",
			  "uri" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgPaintType"),
				values);
	}
	return the_type;
}

GType
lsm_svg_length_direction_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_LENGTH_DIRECTION_ERROR,
			  "LSM_SVG_LENGTH_DIRECTION_ERROR",
			  "error" },
			{ LSM_SVG_LENGTH_DIRECTION_HORIZONTAL,
			  "LSM_SVG_LENGTH_DIRECTION_HORIZONTAL",
			  "horizontal" },
			{ LSM_SVG_LENGTH_DIRECTION_VERTICAL,
			  "LSM_SVG_LENGTH_DIRECTION_VERTICAL",
			  "vertical" },
			{ LSM_SVG_LENGTH_DIRECTION_DIAGONAL,
			  "LSM_SVG_LENGTH_DIRECTION_DIAGONAL",
			  "diagonal" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgLengthDirection"),
				values);
	}
	return the_type;
}

GType
lsm_svg_length_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_LENGTH_TYPE_ERROR,
			  "LSM_SVG_LENGTH_TYPE_ERROR",
			  "error" },
			{ LSM_SVG_LENGTH_TYPE_NUMBER,
			  "LSM_SVG_LENGTH_TYPE_NUMBER",
			  "number" },
			{ LSM_SVG_LENGTH_TYPE_PERCENTAGE,
			  "LSM_SVG_LENGTH_TYPE_PERCENTAGE",
			  "percentage" },
			{ LSM_SVG_LENGTH_TYPE_EMS,
			  "LSM_SVG_LENGTH_TYPE_EMS",
			  "ems" },
			{ LSM_SVG_LENGTH_TYPE_EXS,
			  "LSM_SVG_LENGTH_TYPE_EXS",
			  "exs" },
			{ LSM_SVG_LENGTH_TYPE_PX,
			  "LSM_SVG_LENGTH_TYPE_PX",
			  "px" },
			{ LSM_SVG_LENGTH_TYPE_CM,
			  "LSM_SVG_LENGTH_TYPE_CM",
			  "cm" },
			{ LSM_SVG_LENGTH_TYPE_MM,
			  "LSM_SVG_LENGTH_TYPE_MM",
			  "mm" },
			{ LSM_SVG_LENGTH_TYPE_IN,
			  "LSM_SVG_LENGTH_TYPE_IN",
			  "in" },
			{ LSM_SVG_LENGTH_TYPE_PT,
			  "LSM_SVG_LENGTH_TYPE_PT",
			  "pt" },
			{ LSM_SVG_LENGTH_TYPE_PC,
			  "LSM_SVG_LENGTH_TYPE_PC",
			  "pc" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgLengthType"),
				values);
	}
	return the_type;
}

GType
lsm_svg_fill_rule_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_FILL_RULE_ERROR,
			  "LSM_SVG_FILL_RULE_ERROR",
			  "error" },
			{ LSM_SVG_FILL_RULE_NON_ZERO,
			  "LSM_SVG_FILL_RULE_NON_ZERO",
			  "non-zero" },
			{ LSM_SVG_FILL_RULE_EVEN_ODD,
			  "LSM_SVG_FILL_RULE_EVEN_ODD",
			  "even-odd" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgFillRule"),
				values);
	}
	return the_type;
}

GType
lsm_svg_line_join_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_LINE_JOIN_ERROR,
			  "LSM_SVG_LINE_JOIN_ERROR",
			  "error" },
			{ LSM_SVG_LINE_JOIN_MITER,
			  "LSM_SVG_LINE_JOIN_MITER",
			  "miter" },
			{ LSM_SVG_LINE_JOIN_ROUND,
			  "LSM_SVG_LINE_JOIN_ROUND",
			  "round" },
			{ LSM_SVG_LINE_JOIN_BEVEL,
			  "LSM_SVG_LINE_JOIN_BEVEL",
			  "bevel" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgLineJoin"),
				values);
	}
	return the_type;
}

GType
lsm_svg_line_cap_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_LINE_CAP_ERROR,
			  "LSM_SVG_LINE_CAP_ERROR",
			  "error" },
			{ LSM_SVG_LINE_CAP_BUTT,
			  "LSM_SVG_LINE_CAP_BUTT",
			  "butt" },
			{ LSM_SVG_LINE_CAP_ROUND,
			  "LSM_SVG_LINE_CAP_ROUND",
			  "round" },
			{ LSM_SVG_LINE_CAP_SQUARE,
			  "LSM_SVG_LINE_CAP_SQUARE",
			  "square" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgLineCap"),
				values);
	}
	return the_type;
}

GType
lsm_svg_transform_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_TRANSFORM_TYPE_ERROR,
			  "LSM_SVG_TRANSFORM_TYPE_ERROR",
			  "error" },
			{ LSM_SVG_TRANSFORM_TYPE_MATRIX,
			  "LSM_SVG_TRANSFORM_TYPE_MATRIX",
			  "matrix" },
			{ LSM_SVG_TRANSFORM_TYPE_TRANSLATE,
			  "LSM_SVG_TRANSFORM_TYPE_TRANSLATE",
			  "translate" },
			{ LSM_SVG_TRANSFORM_TYPE_SCALE,
			  "LSM_SVG_TRANSFORM_TYPE_SCALE",
			  "scale" },
			{ LSM_SVG_TRANSFORM_TYPE_ROTATE,
			  "LSM_SVG_TRANSFORM_TYPE_ROTATE",
			  "rotate" },
			{ LSM_SVG_TRANSFORM_TYPE_SKEW_X,
			  "LSM_SVG_TRANSFORM_TYPE_SKEW_X",
			  "skew-x" },
			{ LSM_SVG_TRANSFORM_TYPE_SKEW_Y,
			  "LSM_SVG_TRANSFORM_TYPE_SKEW_Y",
			  "skew-y" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgTransformType"),
				values);
	}
	return the_type;
}

GType
lsm_svg_pattern_units_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_PATTERN_UNITS_ERROR,
			  "LSM_SVG_PATTERN_UNITS_ERROR",
			  "error" },
			{ LSM_SVG_PATTERN_UNITS_USER_SPACE_ON_USE,
			  "LSM_SVG_PATTERN_UNITS_USER_SPACE_ON_USE",
			  "user-space-on-use" },
			{ LSM_SVG_PATTERN_UNITS_OBJECT_BOUNDING_BOX,
			  "LSM_SVG_PATTERN_UNITS_OBJECT_BOUNDING_BOX",
			  "object-bounding-box" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgPatternUnits"),
				values);
	}
	return the_type;
}

GType
lsm_svg_marker_units_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_MARKER_UNITS_ERROR,
			  "LSM_SVG_MARKER_UNITS_ERROR",
			  "error" },
			{ LSM_SVG_MARKER_UNITS_USER_SPACE_ON_USE,
			  "LSM_SVG_MARKER_UNITS_USER_SPACE_ON_USE",
			  "user-space-on-use" },
			{ LSM_SVG_MARKER_UNITS_STROKE_WIDTH,
			  "LSM_SVG_MARKER_UNITS_STROKE_WIDTH",
			  "stroke-width" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgMarkerUnits"),
				values);
	}
	return the_type;
}

GType
lsm_svg_spread_method_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_SPREAD_METHOD_ERROR,
			  "LSM_SVG_SPREAD_METHOD_ERROR",
			  "error" },
			{ LSM_SVG_SPREAD_METHOD_PAD,
			  "LSM_SVG_SPREAD_METHOD_PAD",
			  "pad" },
			{ LSM_SVG_SPREAD_METHOD_REFLECT,
			  "LSM_SVG_SPREAD_METHOD_REFLECT",
			  "reflect" },
			{ LSM_SVG_SPREAD_METHOD_REPEAT,
			  "LSM_SVG_SPREAD_METHOD_REPEAT",
			  "repeat" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgSpreadMethod"),
				values);
	}
	return the_type;
}

GType
lsm_svg_align_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_ALIGN_ERROR,
			  "LSM_SVG_ALIGN_ERROR",
			  "error" },
			{ LSM_SVG_ALIGN_NONE,
			  "LSM_SVG_ALIGN_NONE",
			  "none" },
			{ LSM_SVG_ALIGN_X_MIN_Y_MIN,
			  "LSM_SVG_ALIGN_X_MIN_Y_MIN",
			  "x-min-y-min" },
			{ LSM_SVG_ALIGN_X_MID_Y_MIN,
			  "LSM_SVG_ALIGN_X_MID_Y_MIN",
			  "x-mid-y-min" },
			{ LSM_SVG_ALIGN_X_MAX_Y_MIN,
			  "LSM_SVG_ALIGN_X_MAX_Y_MIN",
			  "x-max-y-min" },
			{ LSM_SVG_ALIGN_X_MIN_Y_MID,
			  "LSM_SVG_ALIGN_X_MIN_Y_MID",
			  "x-min-y-mid" },
			{ LSM_SVG_ALIGN_X_MID_Y_MID,
			  "LSM_SVG_ALIGN_X_MID_Y_MID",
			  "x-mid-y-mid" },
			{ LSM_SVG_ALIGN_X_MAX_Y_MID,
			  "LSM_SVG_ALIGN_X_MAX_Y_MID",
			  "x-max-y-mid" },
			{ LSM_SVG_ALIGN_X_MIN_Y_MAX,
			  "LSM_SVG_ALIGN_X_MIN_Y_MAX",
			  "x-min-y-max" },
			{ LSM_SVG_ALIGN_X_MID_Y_MAX,
			  "LSM_SVG_ALIGN_X_MID_Y_MAX",
			  "x-mid-y-max" },
			{ LSM_SVG_ALIGN_X_MAX_Y_MAX,
			  "LSM_SVG_ALIGN_X_MAX_Y_MAX",
			  "x-max-y-max" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgAlign"),
				values);
	}
	return the_type;
}

GType
lsm_svg_meet_or_slice_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_MEET_OR_SLICE_ERROR,
			  "LSM_SVG_MEET_OR_SLICE_ERROR",
			  "error" },
			{ LSM_SVG_MEET_OR_SLICE_MEET,
			  "LSM_SVG_MEET_OR_SLICE_MEET",
			  "meet" },
			{ LSM_SVG_MEET_OR_SLICE_SLICE,
			  "LSM_SVG_MEET_OR_SLICE_SLICE",
			  "slice" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgMeetOrSlice"),
				values);
	}
	return the_type;
}

GType
lsm_svg_comp_op_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_COMP_OP_ERROR,
			  "LSM_SVG_COMP_OP_ERROR",
			  "error" },
			{ LSM_SVG_COMP_OP_CLEAR,
			  "LSM_SVG_COMP_OP_CLEAR",
			  "clear" },
			{ LSM_SVG_COMP_OP_SRC,
			  "LSM_SVG_COMP_OP_SRC",
			  "src" },
			{ LSM_SVG_COMP_OP_DST,
			  "LSM_SVG_COMP_OP_DST",
			  "dst" },
			{ LSM_SVG_COMP_OP_SRC_OVER,
			  "LSM_SVG_COMP_OP_SRC_OVER",
			  "src-over" },
			{ LSM_SVG_COMP_OP_DST_OVER,
			  "LSM_SVG_COMP_OP_DST_OVER",
			  "dst-over" },
			{ LSM_SVG_COMP_OP_SRC_IN,
			  "LSM_SVG_COMP_OP_SRC_IN",
			  "src-in" },
			{ LSM_SVG_COMP_OP_DST_IN,
			  "LSM_SVG_COMP_OP_DST_IN",
			  "dst-in" },
			{ LSM_SVG_COMP_OP_SRC_OUT,
			  "LSM_SVG_COMP_OP_SRC_OUT",
			  "src-out" },
			{ LSM_SVG_COMP_OP_DST_OUT,
			  "LSM_SVG_COMP_OP_DST_OUT",
			  "dst-out" },
			{ LSM_SVG_COMP_OP_SRC_ATOP,
			  "LSM_SVG_COMP_OP_SRC_ATOP",
			  "src-atop" },
			{ LSM_SVG_COMP_OP_DST_ATOP,
			  "LSM_SVG_COMP_OP_DST_ATOP",
			  "dst-atop" },
			{ LSM_SVG_COMP_OP_XOR,
			  "LSM_SVG_COMP_OP_XOR",
			  "xor" },
			{ LSM_SVG_COMP_OP_PLUS,
			  "LSM_SVG_COMP_OP_PLUS",
			  "plus" },
			{ LSM_SVG_COMP_OP_MULTIPLY,
			  "LSM_SVG_COMP_OP_MULTIPLY",
			  "multiply" },
			{ LSM_SVG_COMP_OP_SCREEN,
			  "LSM_SVG_COMP_OP_SCREEN",
			  "screen" },
			{ LSM_SVG_COMP_OP_OVERLAY,
			  "LSM_SVG_COMP_OP_OVERLAY",
			  "overlay" },
			{ LSM_SVG_COMP_OP_DARKEN,
			  "LSM_SVG_COMP_OP_DARKEN",
			  "darken" },
			{ LSM_SVG_COMP_OP_LIGHTEN,
			  "LSM_SVG_COMP_OP_LIGHTEN",
			  "lighten" },
			{ LSM_SVG_COMP_OP_COLOR_DODGE,
			  "LSM_SVG_COMP_OP_COLOR_DODGE",
			  "color-dodge" },
			{ LSM_SVG_COMP_OP_COLOR_BURN,
			  "LSM_SVG_COMP_OP_COLOR_BURN",
			  "color-burn" },
			{ LSM_SVG_COMP_OP_HARD_LIGHT,
			  "LSM_SVG_COMP_OP_HARD_LIGHT",
			  "hard-light" },
			{ LSM_SVG_COMP_OP_SOFT_LIGHT,
			  "LSM_SVG_COMP_OP_SOFT_LIGHT",
			  "soft-light" },
			{ LSM_SVG_COMP_OP_DIFFERENCE,
			  "LSM_SVG_COMP_OP_DIFFERENCE",
			  "difference" },
			{ LSM_SVG_COMP_OP_EXCLUSION,
			  "LSM_SVG_COMP_OP_EXCLUSION",
			  "exclusion" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgCompOp"),
				values);
	}
	return the_type;
}

GType
lsm_svg_font_stretch_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_FONT_STRETCH_ERROR,
			  "LSM_SVG_FONT_STRETCH_ERROR",
			  "error" },
			{ LSM_SVG_FONT_STRETCH_NORMAL,
			  "LSM_SVG_FONT_STRETCH_NORMAL",
			  "normal" },
			{ LSM_SVG_FONT_STRETCH_ULTRA_CONDENSED,
			  "LSM_SVG_FONT_STRETCH_ULTRA_CONDENSED",
			  "ultra-condensed" },
			{ LSM_SVG_FONT_STRETCH_EXTRA_CONDENSED,
			  "LSM_SVG_FONT_STRETCH_EXTRA_CONDENSED",
			  "extra-condensed" },
			{ LSM_SVG_FONT_STRETCH_CONDENSED,
			  "LSM_SVG_FONT_STRETCH_CONDENSED",
			  "condensed" },
			{ LSM_SVG_FONT_STRETCH_SEMI_CONDENSED,
			  "LSM_SVG_FONT_STRETCH_SEMI_CONDENSED",
			  "semi-condensed" },
			{ LSM_SVG_FONT_STRETCH_SEMI_EXPANDED,
			  "LSM_SVG_FONT_STRETCH_SEMI_EXPANDED",
			  "semi-expanded" },
			{ LSM_SVG_FONT_STRETCH_EXPANDED,
			  "LSM_SVG_FONT_STRETCH_EXPANDED",
			  "expanded" },
			{ LSM_SVG_FONT_STRETCH_EXTRA_EXPANDED,
			  "LSM_SVG_FONT_STRETCH_EXTRA_EXPANDED",
			  "extra-expanded" },
			{ LSM_SVG_FONT_STRETCH_ULTRA_EXPANDED,
			  "LSM_SVG_FONT_STRETCH_ULTRA_EXPANDED",
			  "ultra-expanded" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgFontStretch"),
				values);
	}
	return the_type;
}

GType
lsm_svg_font_style_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_FONT_STYLE_ERROR,
			  "LSM_SVG_FONT_STYLE_ERROR",
			  "error" },
			{ LSM_SVG_FONT_STYLE_NORMAL,
			  "LSM_SVG_FONT_STYLE_NORMAL",
			  "normal" },
			{ LSM_SVG_FONT_STYLE_OBLIQUE,
			  "LSM_SVG_FONT_STYLE_OBLIQUE",
			  "oblique" },
			{ LSM_SVG_FONT_STYLE_ITALIC,
			  "LSM_SVG_FONT_STYLE_ITALIC",
			  "italic" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgFontStyle"),
				values);
	}
	return the_type;
}

GType
lsm_svg_font_weight_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_FONT_WEIGHT_ERROR,
			  "LSM_SVG_FONT_WEIGHT_ERROR",
			  "error" },
			{ LSM_SVG_FONT_WEIGHT_NORMAL,
			  "LSM_SVG_FONT_WEIGHT_NORMAL",
			  "normal" },
			{ LSM_SVG_FONT_WEIGHT_BOLD,
			  "LSM_SVG_FONT_WEIGHT_BOLD",
			  "bold" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgFontWeight"),
				values);
	}
	return the_type;
}

GType
lsm_svg_text_anchor_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_TEXT_ANCHOR_ERROR,
			  "LSM_SVG_TEXT_ANCHOR_ERROR",
			  "error" },
			{ LSM_SVG_TEXT_ANCHOR_START,
			  "LSM_SVG_TEXT_ANCHOR_START",
			  "start" },
			{ LSM_SVG_TEXT_ANCHOR_MIDDLE,
			  "LSM_SVG_TEXT_ANCHOR_MIDDLE",
			  "middle" },
			{ LSM_SVG_TEXT_ANCHOR_END,
			  "LSM_SVG_TEXT_ANCHOR_END",
			  "end" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgTextAnchor"),
				values);
	}
	return the_type;
}

GType
lsm_svg_filter_input_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_FILTER_INPUT_ERROR,
			  "LSM_SVG_FILTER_INPUT_ERROR",
			  "error" },
			{ LSM_SVG_FILTER_INPUT_SOURCE_GRAPHIC,
			  "LSM_SVG_FILTER_INPUT_SOURCE_GRAPHIC",
			  "source-graphic" },
			{ LSM_SVG_FILTER_INPUT_SOURCE_ALPHA,
			  "LSM_SVG_FILTER_INPUT_SOURCE_ALPHA",
			  "source-alpha" },
			{ LSM_SVG_FILTER_INPUT_BACKGROUND_IMAGE,
			  "LSM_SVG_FILTER_INPUT_BACKGROUND_IMAGE",
			  "background-image" },
			{ LSM_SVG_FILTER_INPUT_BACKGROUND_ALPHA,
			  "LSM_SVG_FILTER_INPUT_BACKGROUND_ALPHA",
			  "background-alpha" },
			{ LSM_SVG_FILTER_INPUT_FILL_PAINT,
			  "LSM_SVG_FILTER_INPUT_FILL_PAINT",
			  "fill-paint" },
			{ LSM_SVG_FILTER_INPUT_STROKE_PAINT,
			  "LSM_SVG_FILTER_INPUT_STROKE_PAINT",
			  "stroke-paint" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgFilterInput"),
				values);
	}
	return the_type;
}

GType
lsm_svg_element_category_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ LSM_SVG_ELEMENT_CATEGORY_NONE,
			  "LSM_SVG_ELEMENT_CATEGORY_NONE",
			  "none" },
			{ LSM_SVG_ELEMENT_CATEGORY_DESCRIPTIVE,
			  "LSM_SVG_ELEMENT_CATEGORY_DESCRIPTIVE",
			  "descriptive" },
			{ LSM_SVG_ELEMENT_CATEGORY_CONTAINER,
			  "LSM_SVG_ELEMENT_CATEGORY_CONTAINER",
			  "container" },
			{ LSM_SVG_ELEMENT_CATEGORY_STRUCTURAL,
			  "LSM_SVG_ELEMENT_CATEGORY_STRUCTURAL",
			  "structural" },
			{ LSM_SVG_ELEMENT_CATEGORY_GRAPHICS_REFERENCING,
			  "LSM_SVG_ELEMENT_CATEGORY_GRAPHICS_REFERENCING",
			  "graphics-referencing" },
			{ LSM_SVG_ELEMENT_CATEGORY_GRAPHICS,
			  "LSM_SVG_ELEMENT_CATEGORY_GRAPHICS",
			  "graphics" },
			{ LSM_SVG_ELEMENT_CATEGORY_SHAPE,
			  "LSM_SVG_ELEMENT_CATEGORY_SHAPE",
			  "shape" },
			{ LSM_SVG_ELEMENT_CATEGORY_BASIC_SHAPE,
			  "LSM_SVG_ELEMENT_CATEGORY_BASIC_SHAPE",
			  "basic-shape" },
			{ LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT,
			  "LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT",
			  "text-content" },
			{ LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT_CHILD,
			  "LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT_CHILD",
			  "text-content-child" },
			{ LSM_SVG_ELEMENT_CATEGORY_GRADIENT,
			  "LSM_SVG_ELEMENT_CATEGORY_GRADIENT",
			  "gradient" },
			{ LSM_SVG_ELEMENT_CATEGORY_FILTER_PRIMITIVE,
			  "LSM_SVG_ELEMENT_CATEGORY_FILTER_PRIMITIVE",
			  "filter-primitive" },
			{ LSM_SVG_ELEMENT_CATEGORY_ANIMATION,
			  "LSM_SVG_ELEMENT_CATEGORY_ANIMATION",
			  "animation" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("LsmSvgElementCategory"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmsvgview.h" */
#include "lsmsvgview.h"

GType
lsm_svg_view_surface_type_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ LSM_SVG_VIEW_SURFACE_TYPE_AUTO,
			  "LSM_SVG_VIEW_SURFACE_TYPE_AUTO",
			  "auto" },
			{ LSM_SVG_VIEW_SURFACE_TYPE_IMAGE,
			  "LSM_SVG_VIEW_SURFACE_TYPE_IMAGE",
			  "image" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("LsmSvgViewSurfaceType"),
				values);
	}
	return the_type;
}

/* enumerations from "lsmsvgmatrix.h" */
#include "lsmsvgmatrix.h"

GType
lsm_svg_matrix_flags_get_type (void)
{
	static GType the_type = 0;

	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ LSM_SVG_MATRIX_FLAGS_IDENTITY,
			  "LSM_SVG_MATRIX_FLAGS_IDENTITY",
			  "identity" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("LsmSvgMatrixFlags"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

